pub fn fr<'pokemon_fr>() -> Vec<&'pokemon_fr str> {
    vec![
        // GEN 1
        "Bulbizarre",
        "Herbizarre",
        "Florizarre",
        "Salamèche",
        "Reptincel",
        "Dracaufeu",
        "Carapuce",
        "Carabaffe",
        "Tortank",
        "Chenipan",
        "Chrysacier",
        "Papilusion",
        "Aspicot",
        "Coconfort",
        "Dardargnan",
        "Roucool",
        "Roucoups",
        "Roucarnage",
        "Rattata",
        "Rattatac",
        "Piafabec",
        "Rapasdepic",
        "Abo",
        "Arbok",
        "Pikachu",
        "Raichu",
        "Sabelette",
        "Sablaireau",
        "Nidoran♀",
        "Nidorina",
        "Nidoqueen",
        "Nidoran♂",
        "Nidorino",
        "Nidoking",
        "Mélofée",
        "Mélodelfe",
        "Goupix",
        "Feunard",
        "Rondoudou",
        "Grodoudou",
        "Nosferapti",
        "Nosferalto",
        "Mystherbe",
        "Ortide",
        "Rafflesia",
        "Paras",
        "Parasect",
        "Mimitoss",
        "Aéromite",
        "Taupiqueur",
        "Triopikeur",
        "Miaouss",
        "Persian",
        "Psykokwak",
        "Akwakwak",
        "Férosinge",
        "Colossinge",
        "Caninos",
        "Arcanin",
        "Ptitard",
        "Têtarte",
        "Tartard",
        "Abra",
        "Kadabra",
        "Alakazam",
        "Machoc",
        "Machopeur",
        "Mackogneur",
        "Chétiflor",
        "Boustiflor",
        "Empiflor",
        "Tentacool",
        "Tentacruel",
        "Racaillou",
        "Gravalanch",
        "Grolem",
        "Ponyta",
        "Galopa",
        "Ramoloss",
        "Flagadoss",
        "Magnéti",
        "Magnéton",
        "Canarticho",
        "Doduo",
        "Dodrio",
        "Otaria",
        "Lamantine",
        "Tadmorv",
        "Grotadmorv",
        "Kokiyas",
        "Crustabri",
        "Fantominus",
        "Spectrum",
        "Ectoplasma",
        "Onix",
        "Soporifik",
        "Hypnomade",
        "Krabby",
        "Krabboss",
        "Voltorbe",
        "Électrode",
        "Noeunoeuf",
        "Noadkoko",
        "Osselait",
        "Ossatueur",
        "Kicklee",
        "Tygnon",
        "Excelangue",
        "Smogo",
        "Smogogo",
        "Rhinocorne",
        "Rhinoféros",
        "Leveinard",
        "Saquedeneu",
        "Kangourex",
        "Hypotrempe",
        "Hypocéan",
        "Poissirène",
        "Poissoroy",
        "Stari",
        "Staross",
        "M. Mime",
        "Insécateur",
        "Lippoutou",
        "Élektek",
        "Magmar",
        "Scarabrute",
        "Tauros",
        "Magicarpe",
        "Léviator",
        "Lokhlass",
        "Métamorph",
        "Évoli",
        "Aquali",
        "Voltali",
        "Pyroli",
        "Porygon",
        "Amonita",
        "Amonistar",
        "Kabuto",
        "Kabutops",
        "Ptéra",
        "Ronflex",
        "Artikodin",
        "Électhor",
        "Sulfura",
        "Minidraco",
        "Draco",
        "Dracolosse",
        "Mewtwo",
        "Mew",
        // GEN 2
        "Germignon",
        "Macronium",
        "Méganium",
        "Héricendre",
        "Feurisson",
        "Typhlosion",
        "Kaiminus",
        "Crocrodil",
        "Aligatueur",
        "Fouinette",
        "Fouinar",
        "Hoothoot",
        "Noarfang",
        "Coxy",
        "Coxyclaque",
        "Mimigal",
        "Migalos",
        "Nostenfer",
        "Loupio",
        "Lanturn",
        "Pichu",
        "Mélo",
        "Toudoudou",
        "Togepi",
        "Togetic",
        "Natu",
        "Xatu",
        "Wattouat",
        "Lainergie",
        "Pharamp",
        "Joliflor",
        "Marill",
        "Azumarill",
        "Simularbre",
        "Tarpaud",
        "Granivol",
        "Floravol",
        "Cotovol",
        "Capumain",
        "Tournegrin",
        "Héliatronc",
        "Yanma",
        "Axoloto",
        "Maraiste",
        "Mentali",
        "Noctali",
        "Cornèbre",
        "Roigada",
        "Feuforêve",
        "Zarbi",
        "Qulbutoké",
        "Girafarig",
        "Pomdepik",
        "Foretress",
        "Insolourdo",
        "Scorplane",
        "Steelix",
        "Snubbull",
        "Granbull",
        "Qwilfish",
        "Cizayox",
        "Caratroc",
        "Scarhino",
        "Farfuret",
        "Teddiursa",
        "Ursaring",
        "Limagma",
        "Volcaropod",
        "Marcacrin",
        "Cochignon",
        "Corayon",
        "Rémoraid",
        "Octillery",
        "Cadoizo",
        "Démanta",
        "Airmure",
        "Malosse",
        "Démolosse",
        "Hyporoi",
        "Phanpy",
        "Donphan",
        "Porygon2",
        "Cerfrousse",
        "Queulorior",
        "Debugant",
        "Kapoera",
        "Lippouti",
        "Élekid",
        "Magby",
        "Écrémeuh",
        "Leuphorie",
        "Raikou",
        "Entei",
        "Suicune",
        "Embrylex",
        "Ymphect",
        "Tyranocif",
        "Lugia",
        "Ho-Oh",
        "Celebi",
        // GEN 3
        "Arcko",
        "Massko",
        "Jungko",
        "Poussifeu",
        "Galifeu",
        "Braségali",
        "Gobou",
        "Flobio",
        "Laggron",
        "Medhyèna",
        "Grahyèna",
        "Zigzaton",
        "Linéon",
        "Chenipotte",
        "Armulys",
        "Charmillon",
        "Blindalys",
        "Papinox",
        "Nénupiot",
        "Lombre",
        "Ludicolo",
        "Grainipiot",
        "Pifeuil",
        "Tengalice",
        "Nirondelle",
        "Hélédelle",
        "Goélise",
        "Bekipan",
        "Tarsal",
        "Kirlia",
        "Gardevoir",
        "Arakdo",
        "Maskadra",
        "Balignon",
        "Chapignon",
        "Parecool",
        "Vigoroth",
        "Monaflèmit",
        "Ningale",
        "Ninjask",
        "Munja",
        "Chuchmur",
        "Ramboum",
        "Brouhabam",
        "Makuhita",
        "Hariyama",
        "Azurill",
        "Tarinor",
        "Skitty",
        "Delcatty",
        "Ténéfix",
        "Mysdibule",
        "Galekid",
        "Galegon",
        "Galeking",
        "Méditikka",
        "Charmina",
        "Dynavolt",
        "Élecsprint",
        "Posipi",
        "Négapi",
        "Muciole",
        "Lumivole",
        "Rosélia",
        "Gloupti",
        "Avaltout",
        "Carvanha",
        "Sharpedo",
        "Wailmer",
        "Wailord",
        "Chamallot",
        "Camérupt",
        "Chartor",
        "Spoink",
        "Groret",
        "Spinda",
        "Kraknoix",
        "Vibraninf",
        "Libégon",
        "Cacnea",
        "Cacturne",
        "Tylton",
        "Altaria",
        "Mangriff",
        "Séviper",
        "Séléroc",
        "Solaroc",
        "Barloche",
        "Barbicha",
        "Écrapince",
        "Colhomard",
        "Balbuto",
        "Kaorine",
        "Lilia",
        "Vacilys",
        "Anorith",
        "Armaldo",
        "Barpau",
        "Milobellus",
        "Morphéo",
        "Kecleon",
        "Polichombr",
        "Branette",
        "Skelénox",
        "Téraclope",
        "Tropius",
        "Éoko",
        "Absol",
        "Okéoké",
        "Stalgamin",
        "Oniglali",
        "Obalie",
        "Phogleur",
        "Kaimorse",
        "Coquiperl",
        "Serpang",
        "Rosabyss",
        "Relicanth",
        "Lovdisc",
        "Draby",
        "Drackhaus",
        "Drattak",
        "Terhal",
        "Métang",
        "Métalosse",
        "Regirock",
        "Regice",
        "Registeel",
        "Latias",
        "Latios",
        "Kyogre",
        "Groudon",
        "Rayquaza",
        "Jirachi",
        "Deoxys",
    ]
}
